<template>
  <!-- 物资信息弹窗 -->
  <div>
    <el-dialog :close-on-click-modal="false" :title="`${title}物资信息`" :visible="visible" :before-close="handleClose"
      custom-class="bbsl-location-dialog" width="76%" top="8vh">
      <!-- OCR识别结果 -->
      <div class="orc-content" v-if="OCRContent">
        <div class="orc-title">OCR识别结果:</div>
        <div class="orc-text">{{ OCRContent }}</div>
      </div>
      <el-form ref="formInfo" class="bbsl-scroll-form-spare" :rules="rules" :model="params" label-width="150px">
        <p id="step1" class="from-title">
          <i class="el-icon-info" />
          <span>物资基本信息</span>
        </p>
        <el-row>
          <el-col :span="8">
            <el-form-item label="物资品名：" prop="name">
              <el-input v-model="params.name" clearable maxlength="30" show-word-limit placeholder="请输入品名" />
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="最低库存：" prop="minNumber">
              <el-input type="number" v-model.number="params.minNumber" placeholder="请输入最低库存" clearable maxlength="100"
                controls-position="right" style="width: 100%"/>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="物资编码：" prop="code">
              <el-input v-model="params.code" clearable :disabled="true" maxlength="30" placeholder="请输入编码" />
            </el-form-item>
          </el-col>

          <!-- <el-col :span="8">
  <el-form-item inline="true" label="所属分类：" prop="classId">
    <el-input
      v-model="params.className"
      placeholder="请选择分类"
    />
    <ebs-tree-select
      v-model="params.classId"
      :props="treeSelectProps"
      :options="treeData"
      :disabled="false"
    />
  </el-form-item>
</el-col> -->
        </el-row>
        <el-row>
          <el-col :span="8">
            <el-form-item label="生产厂商：" prop="manufacturer">
              <el-input v-model="params.manufacturer" placeholder="请输入厂商" clearable maxlength="100" show-word-limit />
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="参考单价：" prop="price">
              <el-input type="number" v-model="params.price" controls-position="right" :max="9999999999" clearable
                style="width: 100%" placeholder="请输入参考单价"/>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="单位：" prop="unit">
              <el-select v-model="params.unit" clearable style="width: 100%" maxlength="12" placeholder="请选择的单位">
                <el-option v-for="item in units" :key="item.value" :label="item.name" :value="item.value" />
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="16">
            <el-form-item label="规格型号：" prop="model">
              <el-input v-model="params.model" placeholder="请输入型号" maxlength="100" show-word-limit clearable/>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="排序号：" prop="sn">
              <el-input type="number" v-model="params.sn" controls-position="right" :max="99999" style="width: 100%"
                placeholder="请输入排序号"/>
            </el-form-item>
          </el-col>
        </el-row>

        <el-row>
          <el-col :span="24">
            <el-form-item label="备注：" prop="memo">
              <el-input v-model="params.memo" type="textarea" :autosize="{ minRows: 4 }" maxlength="500" show-word-limit
                placeholder="请输入备注内容" />
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" @click="goInfo">保 存</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>

<script>
import materialInfoManage from '@/api/manager/material/materialInfoManage.js'
import dictUsers from '@/components/dict/DictSelectUtils.js'
import utils from '@/hotent-ui-util.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import CommonApi from '@/views/Manage/CommonApi.js'
import ebsTreeSelect from '@/views/Manage/components/SelectTree.vue'

export default {
  name: 'MaterialInfoFormDialog',
  components: {
    ebsTreeSelect
  },
  props: {
    OCRContent: {
      type: String,
      default: false
    }
  },
  data() {
    return {
      visible: false,
      title: '新增',
      params: {
        minNumber: '',
        name: '', // 品名
        // warehouse: '', //所属仓库
        model: '', // 型号
        quantity: '', // 库存
        code: '', // 编码
        description: '', // 描述
        memo: '', // 备注
        manufacturer: '', // 厂商
        id: null,
        classId: null,
        className: '',
        unit: '', // 单位
        sn: 0 // 排序号
      },
      activeCollapse: '1',
      search: '',
      title1: '选择',
      // TableData: [], //单位弹窗列表信息
      rules: {
        name: [
          {
            required: true,
            message: '请输入品名',
            trigger: 'blur'
          }
        ],
        minNumber: [
          {
            required: true,
            message: '请输入最低库存',
            trigger: 'blur'
          }
        ]
      },
      units: [],
      treeData: [
        {
          code: '',
          id: 0,
          typeName: '物资分类信息',
          parentId: 0,
          children: []
        }
      ],
      treeSelectProps: {
        value: 'id', // ID字段名
        label: 'typeName', // 显示名称
        children: 'children' // 子级字段名
      }
    }
  },
  mounted() {
    materialInfoManage.loadAllClass({}, (res) => {
      this.treeData[0].children = res
    })
  },
  created() {
    this.units = dictContracts.getDictItemsFromCache('cmgt_wzdwmc')
  },
  methods: {
    add(row) {
      this.params.classId = row.id
      this.params.className = row.typeName

      CommonApi.getNextCodeByAlias('wzbh', (res) => {
        this.params.code = res.value
      })

      //   materialInfoManage.getMaterialCode(res => {
      // 	  this.params.code = res.value
      //   })
      this.params.unit = this.units[0].value
      this.visible = true
    },
    // 保存人员信息
    goInfo() {
      this.$refs.formInfo.validate((valid) => {
        if (valid) {
          if (this.title === '新增') {
            materialInfoManage
              .addMaterialInfo(this.params)
              .then((response) => {
                if (response.state) {
                  this.$notify({
                    type: 'success',
                    message: '新增成功',
                    duration: 2000
                  })
                  this.handleClose()
                  this.$parent.loadData(1)
                }
              })
          }
          if (this.title === '修改') {
            console.log('==============', this.params)
            materialInfoManage
              .updateMaterialInfo(this.params)
              .then((response) => {
                if (response.state) {
                  this.$notify({
                    type: 'success',
                    message: '修改成功',
                    duration: 2000
                  })
                  this.handleClose()
                  this.$parent.loadData(1)
                }
              })
          }
        } else {
          return false
        }
      })
    },
    edit(row) {
      this.params = utils.deepClone(row)
      this.visible = true
      this.title = '修改'
    },
    // 关闭新增人员窗口
    handleClose() {
      this.params = {
        minNumber: '',
        name: '', // 品名
        // warehouse: '', //所属仓库
        model: '', // 型号
        quantity: '', // 库存
        code: '', // 人员编码
        description: '', // 描述
        memo: '', // 备注
        sn: 0, // 排序号
        manufacturer: '', // 厂商
        id: null,
        classId: null,
        className: null,
        unit: '' // 单位
      }
      this.$refs.formInfo.clearValidate()
      this.title = '新增'
      this.visible = false
    }
  }
}
</script>

<style lang="scss" scoped>
.company-type ::v-deep .el-checkbox-group {
  height: initial !important;
}

.orc-content {
  width: 99%;
  border: 1px dashed #c5c3c3;
  padding: 6px 10px 10px 10px;

  .orc-title {
    color: #409eff;
    font-weight: 700;
    font-size: 14px;
    user-select: none;
  }

  .orc-text {
    margin-top: 5px;
    min-height: 100px;
    max-height: 400px;
    overflow-y: auto;
  }
}
</style>
